@@ -1,4 +1,6 @@
 import requests
+import platform
+from . import __version__
 
 class EvntalySDK:
     """
@@ -42,6 +44,7 @@ class EvntalySDK:
     def track(self, event_data: dict):
         """
         Tracks an event if tracking is enabled and within limits.
+        Automatically attaches SDK context data.
         """
         if not self.tracking_enabled:
             print("Tracking is disabled. Event not sent.")
@@ -51,6 +54,14 @@ class EvntalySDK:
             print("checkLimit returned false. Event not sent.")
             return
 
+        # Attach SDK context automatically
+        event_data = event_data.copy()  # Avoid mutating the original
+        event_data["context"] = {
+            "sdkVersion": __version__,
+            "sdkRuntime": f"Python {platform.python_version()}",
+            "operatingSystem": platform.system(),
+        }
+
         url = f"{self.BASE_URL}/api/v1/register/event"
         headers = {
             "Content-Type": "application/json",
